@@ -1,7 +1,7 @@
 /*****************************************************************************\
  *  $Id: genders.c,v 1.146 2010-02-02 00:04:34 chu11 Exp $
  *****************************************************************************
- *  Copyright (C) 2007-2010 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2011 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2001-2007 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Jim Garlick <garlick@llnl.gov> and Albert Chu <chu11@llnl.gov>.
@@ -218,8 +218,10 @@ genders_load_data(genders_t handle, const char *filename)
   handle->nodename[GENDERS_MAXHOSTNAMELEN]='\0';
 
   /* shorten hostname if necessary */
+#ifndef WITH_NON_SHORTENED_HOSTNAMES
   if ((temp = strchr(handle->nodename,'.')))
     *temp = '\0';
+#endif /* !WITH_NON_SHORTENED_HOSTNAMES */
   
   handle->maxnodelen = GENDERS_MAX(strlen(handle->nodename), handle->maxnodelen);
 
